<?php

    function prepareRegDates($reg_dates = null) {

        if (null === $reg_dates) {
            throw new Exception('No reg_dates given.');
        }

        $unique_items = array();
        $return = array();

        foreach ($reg_dates as $reg_date) {

            $reg_date_key = substr($reg_date->Value, 0, 4) . '-' . substr($reg_date->Value, 5, 2) . '-' . '01';

            if (in_array($reg_date_key, $unique_items)) {
                unset($reg_date);
                continue;
            }

            $new_reg_date = new stdClass();
            $new_reg_date->Key   = $reg_date_key;
            $new_reg_date->Value = substr($reg_date->Value, 5, 2) . ' / ' . substr($reg_date->Value, 0, 4);

            array_push($unique_items, $reg_date_key);
            array_push($return, $new_reg_date);
        }

        return $return;
    }

    function preparePowers($power_values = null) {

        if (null === $power_values) {
            throw new Exception('No power values given.');
        }

        foreach ($power_values as &$power) {
            $power->Value = $power->Value . ' kW';
        }

        return $power_values;
    }

    function prepareKms($km_values = null) {

        if (null === $km_values) {
            throw new Exception('No km values given.');
        }

        foreach ($km_values as &$km) {
            $km->Value = number_format(intval($km->Value), 0, ',', '.');
        }

        return $km_values;
    }

    function preparePrices($price_values = null) {

        if (null === $price_values) {
            throw new Exception('No price values given.');
        }

        foreach ($price_values as &$price) {
            $price->Value = number_format($price->Value, 2, ',', '.') . ' EUR';
        }

        return $price_values;
    }

    function getUniquedAccsList($accslist = null) {

        if (null === $accslist) {
            throw new Exception('No AccsList values given.');
        }

        $unique_items = array();
        foreach ($accslist as $accs) {

            $unique_items = array_merge($unique_items, explode(',', $accs->Key));
        }

        $return = array_values(array_unique($unique_items));
        sort($return, SORT_STRING);

        return $return;
    }

    /**
     * Convert AccsList into array of objects. Key will contain value.
     *
     * {
     *     Key: I01,
     *     Value: 2
     * }
     *        --->
     * {
     *     Key: I01.2,
     *     Value: 2
     * }
     *
     *
     * @param  stdClass $accslist
     * @return array
     */
    function prepareAccsList($accslist = null) {

        if (null === $accslist) {
            throw new Exception('No AccsList values given.');
        }

        $return = array();
        foreach ($accslist->Accs as &$accslist_item) {

            if (empty($accslist_item->Key)) {
                continue;
            }

            $accslist_item->Key .= '.' . $accslist_item->Value;

            array_push($return, $accslist_item);
        }

        return $return;
    }

    function parseBBCode($bbcode_string = null) {

        if (null === $bbcode_string) {
            throw new Exception('No BBCode given.');
        }

        require_once APP_DIR . 'engine' . DIRECTORY_SEPARATOR . 'stringparser_bbcode.class.php';

        $bbcode = new StringParser_BBCode ();


        $bbcode->addCode ('b', 'simple_replace', null, array('start_tag' => '<span class="bold">', 'end_tag' => '</span>'),
                            'inline', array('block', 'inline'), array());

        $bbcode->addCode ('ul', 'simple_replace', null, array('start_tag' => '<ul>', 'end_tag' => '</ul>'),
                            'block', array('block'), array());

        $bbcode->addCode ('li', 'simple_replace', null, array('start_tag' => '<li>', 'end_tag' => '</li>'),
                            'block', array('block'), array());

        $bbcode->addCode ('br', 'simple_replace', null, array('start_tag' => '<br>', 'end_tag' => '</br>'),
                            'block', array('block', 'inline'), array());

        $bbcode->addCode ('hr', 'simple_replace', null, array('start_tag' => '<hr>', 'end_tag' => '</hr>'),
                            'block', array('block', 'inline'), array());

        return $bbcode->parse($bbcode_string);
    }

?>